==> GameboyAdvanceVM-Project-0.02.zip: win32/DispcntDlg.h <==
#if !defined(AFX_DISPCNTDLG_H__B2970414_A5B0_4177_B244_D113EEF7805D__INCLUDED_)
#define AFX_DISPCNTDLG_H__B2970414_A5B0_4177_B244_D113EEF7805D__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// DispcntDlg.h : wb_[ t@C
//

/////////////////////////////////////////////////////////////////////////////
// CDispcntDlg _CAO

class CDispcntDlg : public CDialog
{
// RXgNV
public:
	CDispcntDlg(CWnd* pParent = NULL);   // W̃RXgN^
	void OnOK();
	void OnCancel();
	void ShowDispcnt();
	void DrawDispcntLcd();
	void DrawDispcntPlatte();
	UINT m_temp_mode;
	BYTE DispBuffer[240 * 160 * 2];

// _CAO f[^
	//{{AFX_DATA(CDispcntDlg)
	enum { IDD = IDD_DISPCNT };
	//}}AFX_DATA


// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CDispcntDlg)
	public:
	virtual BOOL PreTranslateMessage(MSG* pMsg);
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV T|[g
	//}}AFX_VIRTUAL

// Cve[V
protected:

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CDispcntDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnClose();
	afx_msg void OnPaint();
	afx_msg void OnButtonUpdate();
	afx_msg void OnRadioMode0();
	afx_msg void OnRadioMode1();
	afx_msg void OnRadioMode2();
	afx_msg void OnRadioMode3();
	afx_msg void OnRadioMode4();
	afx_msg void OnRadioMode5();
	afx_msg void OnRadioMode6();
	afx_msg void OnRadioMode7();
	afx_msg void OnButtonDummyPalette();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_DISPCNTDLG_H__B2970414_A5B0_4177_B244_D113EEF7805D__INCLUDED_)

==> GameboyAdvanceVM-Project-0.03.zip: win32/DispcntDlg.h <==
#if !defined(AFX_DISPCNTDLG_H__B2970414_A5B0_4177_B244_D113EEF7805D__INCLUDED_)
#define AFX_DISPCNTDLG_H__B2970414_A5B0_4177_B244_D113EEF7805D__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// DispcntDlg.h : wb_[ t@C
//

/////////////////////////////////////////////////////////////////////////////
// CDispcntDlg _CAO

class CDispcntDlg : public CDialog
{
// RXgNV
public:
	CDispcntDlg(CWnd* pParent = NULL);   // W̃RXgN^
	void OnOK();
	void OnCancel();
	void ShowDispcnt();
	void DrawDispcntLcd();
	void DrawDispcntPalette();
	UINT m_temp_dispcnt;
	WORD DispBuffer[240 * 160];

// _CAO f[^
	//{{AFX_DATA(CDispcntDlg)
	enum { IDD = IDD_DISPCNT };
	//}}AFX_DATA


// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CDispcntDlg)
	public:
	virtual BOOL PreTranslateMessage(MSG* pMsg);
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV T|[g
	//}}AFX_VIRTUAL

// Cve[V
protected:

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CDispcntDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnClose();
	afx_msg void OnPaint();
	afx_msg void OnButtonUpdate();
	afx_msg void OnRadioMode0();
	afx_msg void OnRadioMode1();
	afx_msg void OnRadioMode2();
	afx_msg void OnRadioMode3();
	afx_msg void OnRadioMode4();
	afx_msg void OnRadioMode5();
	afx_msg void OnRadioMode6();
	afx_msg void OnRadioMode7();
	afx_msg void OnButtonDummyPalette();
	afx_msg void OnCheckBg0();
	afx_msg void OnCheckBg1();
	afx_msg void OnCheckBg2();
	afx_msg void OnCheckBg3();
	afx_msg void OnCheckWin1();
	afx_msg void OnCheckWin2();
	afx_msg void OnCheckWinobj();
	afx_msg void OnCheckBackbuffer();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_DISPCNTDLG_H__B2970414_A5B0_4177_B244_D113EEF7805D__INCLUDED_)
